bayespy.nodes.Poisson
=====================

.. currentmodule:: bayespy.nodes

.. autoclass:: Poisson

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~Poisson.__init__
      ~Poisson.add_plate_axis
      ~Poisson.broadcasting_multiplier
      ~Poisson.delete
      ~Poisson.get_gradient
      ~Poisson.get_mask
      ~Poisson.get_moments
      ~Poisson.get_parameters
      ~Poisson.get_riemannian_gradient
      ~Poisson.get_shape
      ~Poisson.has_plotter
      ~Poisson.initialize_from_parameters
      ~Poisson.initialize_from_prior
      ~Poisson.initialize_from_random
      ~Poisson.initialize_from_value
      ~Poisson.load
      ~Poisson.logpdf
      ~Poisson.lower_bound_contribution
      ~Poisson.lowerbound
      ~Poisson.move_plates
      ~Poisson.observe
      ~Poisson.pdf
      ~Poisson.plot
      ~Poisson.random
      ~Poisson.save
      ~Poisson.set_parameters
      ~Poisson.set_plotter
      ~Poisson.show
      ~Poisson.unobserve
      ~Poisson.update
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~Poisson.dims
      ~Poisson.plates
      ~Poisson.plates_multiplier
   
   